kicad_netlist_reader
====================

KiCad python module for interpreting generic netlists which can be
used to generate Bills of materials, etc. Simple repackaging of the
original Kicad source file.

Authors:

    Jean-Pierre Charras jean-pierre.charras[at]gipsa-lab-dot-inpg-dot-fr

Package Maintainers:

    Peter Polidoro <peterpolidoro@gmail.com>

License:

    GPL
